pub struct GetArgs {
pub identifier: String,
pub common: GlobalArgs,
pub id: bool,
pub cve: bool,
pub ghsa: bool,
pub package: bool,
pub save_only: bool,
pub one_off: bool,
}Fields
identifier: StringPatch identifier (UUID, CVE ID, GHSA ID, PURL, or package name).
common: GlobalArgsid: boolForce identifier to be treated as a patch UUID.
cve: boolForce identifier to be treated as a CVE ID.
ghsa: boolForce identifier to be treated as a GHSA ID.
package: boolForce identifier to be treated as a package name.
save_only: boolDownload patch without applying it.
one_off: boolApply patch immediately without saving to .socket folder.