find_packages_for_purls

Function find_packages_for_purls 

pub async fn find_packages_for_purls(
    partitioned: &HashMap<Ecosystem, Vec<String>>,
    options: &CrawlerOptions,
    silent: bool,
) -> HashMap<String, PathBuf>
For each ecosystem in the partitioned map, create the crawler, discover source paths, and look up the given PURLs. Returns a unified purl -> path map.