Module ecosystem_dispatch

Module ecosystem_dispatch 

Functions

crawl_all_ecosystems
Crawl all enabled ecosystems and return all packages plus per-ecosystem counts.
find_packages_for_purls
For each ecosystem in the partitioned map, create the crawler, discover source paths, and look up the given PURLs. Returns a unified purl -> path map.
find_packages_for_rollback
Variant of find_packages_for_purls for rollback, which needs to remap pypi qualified PURLs (with ?artifact_id=...) to the base PURL found by the crawler.
partition_purls
Partition PURLs by ecosystem, filtering by the --ecosystems flag if set.